# User Profile
### On this page
  * [Updating Your User Profile](https://help.sap.com/docs/leanix/ea/user-profile#updating-your-user-profile)
  * [Changing Your Password](https://help.sap.com/docs/leanix/ea/user-profile#changing-your-password)
  * [Resetting Your Password](https://help.sap.com/docs/leanix/ea/user-profile#resetting-your-password)


Manage your user profile settings. Change or reset your password if needed.
